searchData={"items":[{"type":"module","title":"CVA","doc":"Construct classes with variant definitions.\n\nA variant consists of a name and a class. These variants are defined by providing a declarative\nset of nested keyword lists.\n\n    defmodule MyCVA do\n      import CVA\n\n      def button(props) do\n        config = [\n          variants: [\n            intent: [\n              primary: \"bg-cyan-600\",\n              secondary: \"bg-zinc-700\",\n              destructive: \"bg-red-500\"\n            ],\n            size: [\n              xs: \"rounded px-2.5 py-1.5 text-xs\",\n              sm: \"rounded-md px-3 py-2 text-sm\",\n              md: \"rounded-md px-4 py-2 text-sm\",\n              lg: \"rounded-md px-4 py-2 text-base\",\n              xl: \"rounded-md px-6 py-3 text-base\"\n            ]\n          ]\n        ]\n\n        cva(config, props)\n      end\n    end\n\n  Invoking `button/1` with the desired variants will return a class name including\n  the classes specified in the config.\n\n      button(intent: :primary, size: :md) # -> \"bg-cyan-600 rounded-md px-4 py-2 text-sm\"\n\n  See `cva/3` for more info.","ref":"CVA.html"},{"type":"module","title":"Usage with Phoenix function components. - CVA","doc":"CVA integrates nicely with Phoenix function components by providing `variant/3` and\n  `compound_variant/2` macros.\n\n  Please refer to the `CVA.Component` module.","ref":"CVA.html#module-usage-with-phoenix-function-components"},{"type":"function","title":"CVA.cva/1","doc":"See `cva/3`.","ref":"CVA.html#cva/1"},{"type":"function","title":"CVA.cva/2","doc":"See `cva/3`.","ref":"CVA.html#cva/2"},{"type":"function","title":"CVA.cva/3","doc":"Construct a class string from a variant configuration.\n\nAccepts a base class string, a variant configuration, and a list of props.\n\n    config = [\n      variants: [\n        intent: [\n          primary: \"bg-cyan-600\",\n          secondary: \"bg-zinc-700\",\n          destructive: \"bg-red-500\"\n        ],\n        size: [\n          xs: \"rounded px-2.5 py-1.5 text-xs\",\n          sm: \"rounded-md px-3 py-2 text-sm\",\n          md: \"rounded-md px-4 py-2 text-sm\",\n          lg: \"rounded-md px-4 py-2 text-base\",\n          xl: \"rounded-md px-6 py-3 text-base\"\n        ]\n      ],\n      default_variants: [\n        intent: :secondary,\n        size: :md\n      ],\n      compound_variants: [\n        [intent: :primary, size: :xl, class: \"uppercase\"]\n      ]\n    ]\n\n    cva(\"base\", config, intent: :primary, size: :md) # -> \"base bg-cyan-600 rounded-md px-4 py-2 text-sm\"\n    cva(\"base\", config, intent: :primary, size: :xl) # -> \"base bg-cyan-600 rounded-md px-6 py-3 text-base uppercase\"\n    cva(\"base\", config, intent: :primary, size: :xl) # -> \"base bg-cyan-600 rounded-md px-6 py-3 text-base uppercase\"\n\n    cva(\"base\", config) # -> \"base bg-zinc-700 rounded-md px-4 py-2 text-sm\"\n    cva(\"base\", config, intent: :primary) # -> \"base bg-cyan-600 rounded-md px-4 py-2 text-sm\"","ref":"CVA.html#cva/3"},{"type":"function","title":"Config - CVA.cva/3","doc":"The configuration is a keyword list with the following keys:\n\n  * `:variants` - A keyword list of variants. Each variant is a keyword list of\n    variant names and classes.\n  * `:compound_variants` - A list of compound variants. Each compound\n    variant is a keyword list of required variants and a `:class` key to specify the class\n    which should be applied if all variants are present.\n  * `:default_variants` - A keyword list of default variants. For example `[intent: :primary]`.","ref":"CVA.html#cva/3-config"},{"type":"function","title":"Props - CVA.cva/3","doc":"Props define the variants to be applied. Each key in the props list must be a variant name.\nValues can either be an atom or a string.","ref":"CVA.html#cva/3-props"},{"type":"function","title":"Special props - CVA.cva/3","doc":"* `:class` - A class string or list of classes. This class is applied last.","ref":"CVA.html#cva/3-special-props"},{"type":"function","title":"CVA.cx/1","doc":"Merges a list of classes into a single class string removing any nil or empty strings.\nClass lists can be infinitely nested.","ref":"CVA.html#cx/1"},{"type":"module","title":"CVA.Component","doc":"Integrates CVA with Phoenix function components.\n\nThe `variant/3` and `compound_variant/2` macros allow easy definition of variants and compound\nvariants for a component. This also includes compile time checks for the specified variants.\n\nWhen using this module, please make sure that you add include :cva to your imports in\n`.formatter.exs`.\n\n```elixir\n[\n  import_deps: [:cva],\n]\n```","ref":"CVA.Component.html"},{"type":"module","title":"Usage - CVA.Component","doc":"defmodule MyWeb.Components do\n      use CVA.Component\n\n      variant :intent, [\n          primary: \"bg-cyan-600\",\n          secondary: \"bg-zinc-700\",\n          destructive: \"bg-red-500\"\n        ],\n        default: :secondary\n\n      variant :size, [\n          xs: \"rounded px-2.5 py-1.5 text-xs\",\n          sm: \"rounded-md px-3 py-2 text-sm\",\n          md: \"rounded-md px-4 py-2 text-sm\",\n          lg: \"rounded-md px-4 py-2 text-base\",\n          xl: \"rounded-md px-6 py-3 text-base\"\n        ],\n        default: :md\n\n      compound_variant \"uppercase\", intent: :primary, size: :xl\n\n      attr :rest, :global\n      slot :inner_block\n\n      def button(assigns) do\n        ~H\"\"\"\n         <%= render_slot(@inner_block) %> \n        \"\"\"\n      end\n    end\n\n    defmodule MyWeb.SomeLive do\n      import MyWeb.Components\n\n      def render(assigns) do\n        ~H\"\"\"\n        <.button intent=\"primary\">Click me</.button>\n        \"\"\"\n      end\n    end","ref":"CVA.Component.html#module-usage"},{"type":"macro","title":"CVA.Component.compound_variant/2","doc":"Declares a compound variant for HEEx function components.\n\nA compound variant defines a set of required variants. If all variants are present, the\ngiven class will be assigned.\n\nA component can have multiple compound variants.","ref":"CVA.Component.html#compound_variant/2"},{"type":"macro","title":"Arguments - CVA.Component.compound_variant/2","doc":"* `class` - the class to add if all variants are present.\n\n  * `variants` - a keyword list of required variants.","ref":"CVA.Component.html#compound_variant/2-arguments"},{"type":"macro","title":"Example - CVA.Component.compound_variant/2","doc":"defmodule MyWeb.Components do\n      use CVA.Component\n\n      variant :intent, [\n          primary: \"bg-cyan-600\",\n          secondary: \"bg-zinc-700\",\n        ],\n        default: :secondary\n\n      variant :size, [\n          md: \"rounded-md px-4 py-2 text-sm\",\n          xl: \"rounded-md px-6 py-3 text-base\"\n        ],\n        default: :md\n\n      compound_variant \"uppercase\", intent: :primary, size: :xl\n\n      def button(assigns) do\n        ~H\"\"\"\n         <%= render_slot(@inner_block) %> \n        \"\"\"\n      end\n    end","ref":"CVA.Component.html#compound_variant/2-example"},{"type":"macro","title":"CVA.Component.variant/3","doc":"Declares a variant for HEEx function components.\n\nWhen declaring variants, an assign `cva_class` is added to the component. This assign contains\nthe class according to all variant definitions of the component. This class is intended to\nbe passed into the `class` attribute of the component.\n\nA component can have multiple variants.","ref":"CVA.Component.html#variant/3"},{"type":"macro","title":"Arguments - CVA.Component.variant/3","doc":"* `name` - an atom defining the name of the attribute. Note that attributes cannot define the\n  same name as any other attributes or slots or attributes declared for the same component.\n\n  * `variants` - a keyword list of variants. Supported variant values are strings and a list of strings.\n\n  * `opts` - a keyword list of options. Defaults to `[]`.","ref":"CVA.Component.html#variant/3-arguments"},{"type":"macro","title":"Options - CVA.Component.variant/3","doc":"* `default` - the default variant.\n\n    All other options will be passed to `Phoenix.Component.attr/3`.","ref":"CVA.Component.html#variant/3-options"},{"type":"macro","title":"Example - CVA.Component.variant/3","doc":"defmodule MyWeb.Components do\n      use CVA.Component\n\n      variant :intent, [\n          primary: \"bg-cyan-600\",\n          secondary: \"bg-zinc-700\",\n          destructive: \"bg-red-500\"\n        ],\n        default: :secondary\n\n      variant :size, [\n          xs: \"rounded px-2.5 py-1.5 text-xs\",\n          sm: \"rounded-md px-3 py-2 text-sm\",\n          md: \"rounded-md px-4 py-2 text-sm\",\n          lg: \"rounded-md px-4 py-2 text-base\",\n          xl: \"rounded-md px-6 py-3 text-base\"\n        ],\n        default: :md\n\n      def button(assigns) do\n        ~H\"\"\"\n         <%= render_slot(@inner_block) %> \n        \"\"\"\n      end\n    end","ref":"CVA.Component.html#variant/3-example"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.35.1"}}